@@ -20,5 +20,5 @@ NULL
 #' sem_disc <- glmdisc(x,y,iter=50,m_start=4,test=FALSE,validation=FALSE,criterion="aic")
 #' discretize(sem_disc,data.frame(x))
 methods::setMethod("discretize", methods::signature(object="glmdisc"), function(object,data) {
-     glmdisc:::discretize_link(object@best.disc[[2]],data,object@parameters$m_start)
+     discretize_link(object@best.disc[[2]],data,object@parameters$m_start)
 })
\ No newline at end of file
